package com.gisdo.opengis.Controller;

import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.tomcat.util.http.fileupload.ByteArrayOutputStream;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.io.FileSystemResource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.util.Objects;

@CrossOrigin
@RestController
@RequestMapping("/file")
public class FileController {
    @Value("${uploadFilePath}")
    private final String pdfFilePath = "F:\\下载\\aspnet core-8.0官方手册.pdf"; // 替换为您的 PDF 文件路径
    private  String uploadDir;

    @PostMapping("/uploadfile")
    public ResponseEntity<String> uploadFile(@RequestBody MultipartFile file) {
        if (file.isEmpty()) {
            return ResponseEntity.status(HttpStatus.BAD_REQUEST).body("文件为空");
        }
        try {
            // 创建上传目录
            File dir = new File(uploadDir);
            if (!dir.exists()) {
                dir.mkdirs();
            }

            // 保存文件
            File uploadedFile = new File(dir, Objects.requireNonNull(file.getOriginalFilename()));
            file.transferTo(uploadedFile);

            return ResponseEntity.ok("文件上传成功: " + uploadedFile.getAbsolutePath());
        } catch (IOException e) {
            return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).body("上传失败: " + e.getMessage());
        }
    }

    @GetMapping("/downloadfile")
    public ResponseEntity<byte[]> downloadExcelFile() {
        Workbook workbook = new XSSFWorkbook();
        Sheet sheet = workbook.createSheet("数据");
        // 创建表头
        Row header = sheet.createRow(0);
        header.createCell(0).setCellValue("列1");
        header.createCell(1).setCellValue("列2");
        header.createCell(2).setCellValue("列3");
        // 添加一些示例数据
        for (int i = 1; i <= 10; i++) {
            Row row = sheet.createRow(i);
            row.createCell(0).setCellValue("数据 " + i + " - 1");
            row.createCell(1).setCellValue("数据 " + i + " - 2");
            row.createCell(2).setCellValue("数据 " + i + " - 3");
        }
        // 写入到字节数组
        try (ByteArrayOutputStream outputStream = new ByteArrayOutputStream()) {
            workbook.write(outputStream);
            workbook.close();
            // 设置响应头
            HttpHeaders headers = new HttpHeaders();
            headers.add("Content-Disposition", "attachment; filename=data.xlsx");
            headers.add("Content-Type", "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet");
            return new ResponseEntity<>(outputStream.toByteArray(), headers, HttpStatus.OK);
        } catch (IOException e) {
            return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).body(null);
        }
    }
    @GetMapping("/downloadpdf")
    public ResponseEntity<FileSystemResource> downloadPdfFile() {
        File pdfFile = new File(pdfFilePath);

        if (!pdfFile.exists()) {
            return ResponseEntity.status(HttpStatus.NOT_FOUND).body(null);
        }
        HttpHeaders headers = new HttpHeaders();
        headers.add(HttpHeaders.CONTENT_DISPOSITION, "attachment; filename=" + pdfFile.getName());
        return ResponseEntity.ok()
                .headers(headers)
                .contentLength(pdfFile.length())
                .contentType(MediaType.APPLICATION_PDF)
                .body(new FileSystemResource(pdfFile));
    }
}
